@@ -358,11 +358,11 @@ class Sequential():
                             axs1[1].set_xlabel("Epoch")
                             axs1[1].set_ylabel("Accuracy")
                             
-                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)}")
-                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}")
+                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {round(float(self.train_loss_records[-1]), 3)}")
+                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {round(float(self.train_accuracy_records[-1]), 3)}")
                             if self.val_inputs is not None and self.val_targets is not None:
-                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)}")
-                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
+                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {round(float(self.val_loss_records[-1]), 3)}")
+                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {round(float(self.val_accuracy_records[-1]), 3)}")
                                 
                             axs1[0].legend()
                             axs1[1].legend()
@@ -411,11 +411,11 @@ class Sequential():
                             axs1[1].set_xlabel("Epoch")
                             axs1[1].set_ylabel("Accuracy")
                             
-                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)}")
-                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}")
+                            axs1[0].plot(self.train_loss_records, color="#1f77b4", label=f"training dataset: {round(float(self.train_loss_records[-1]), 3)}")
+                            axs1[1].plot(self.train_accuracy_records, color="#1f77b4", label=f"training dataset: {round(float(self.train_accuracy_records[-1]), 3)}")
                             if self.val_inputs is not None and self.val_targets is not None:
-                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)}")
-                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
+                                axs1[0].plot(self.val_loss_records, color="orange", label=f"validation dataset: {round(float(self.val_loss_records[-1]), 3)}")
+                                axs1[1].plot(self.val_accuracy_records, color="orange", label=f"validation dataset: {round(float(self.val_accuracy_records[-1]), 3)}")
                             
                             axs1[0].legend()
                             axs1[1].legend()
